// Ca marche! // Operating!

import g4p_controls.*;
import processing.serial.*;

// Variables et structures globales // Global variables ans structures
int g_winW             = 450;       // Largeur Fenêtre // Window Width 
int g_winH             = 400;       // Hauteur Fenêtre // Window Height
PFont  g_font;        
Serial g_serial;
String MaConsigne, MaMesure, MonPWM, MaSondeEnTest, ChaineEntree;
GCustomSlider sdr1, sdr2, sdr3, sdr4;

// Définition de l'environnement graphique et des glissières
// Defining graphics and sliders
void setup() {  
  size(g_winW, g_winH);  
  g_font = loadFont("ArialMT-20.vlw");
  textFont(g_font, 20);

  // Indicateur de consigne: valeur du potentiomètre cadrée entre 0° et 100°C
  // Reference point definition: potentiometer casted between 0°C and 100°C
  sdr1 = new GCustomSlider(this, 20, 20, 260, 50, "blue18px");
  sdr1.setNumberFormat(G4P.DECIMAL, 1);
  sdr1.setLimits(25f, 0f, 100f);
  sdr1.setShowValue(true); 


  // Indicateur de mesure du banc: température du LM35 entre 0° et 100°C
  // Bench temperature: between 0°C and 100°C
  sdr2 = new GCustomSlider(this, 20, 80, 260, 50, "red_yellow18px");
  sdr2.setShowDecor(false, true, true, true);
  sdr2.setNbrTicks(11);
  sdr2.setNumberFormat(G4P.DECIMAL, 1);
  sdr2.setLimits(25f, 0f, 100f);
  sdr2.setShowValue(true); 

  // Indicateur de puissance de chauffe: 0-100%
  // Heating power indicator: 0-100%
  sdr3 = new GCustomSlider(this, 20, 140, 260, 50, "purple18px");
  sdr3.setShowDecor(false, true, true, true);
  sdr3.setNbrTicks(0);
  sdr3.setEasing(20);
  sdr3.setLimits(0f, 0f, 100f);
  sdr3.setNumberFormat(G4P.INTEGER);

  // Indicateur de mesure de la sonde en test: 0° à 100°C, pas utilisé, mesure manuelle
  // Under test probe temperature: between 0°C and 100°C, not used, manuel measure
  sdr4 = new GCustomSlider(this, 20, 260, 260, 50, "red_yellow18px");
  sdr4.setShowDecor(false, true, true, true);
  sdr4.setNbrTicks(11);
  sdr4.setNumberFormat(G4P.DECIMAL, 1);
  sdr4.setLimits(25f, 0f, 100f);
  sdr4.setShowValue(true); 

  // Liste de tous les ports série
  // Collecting all serial ports
  println(Serial.list());
  // Le premier port est Arduino (numéro 0)
  // The first of them is Arduino (number 0)
  g_serial = new Serial(this, Serial.list()[5], 19200);
  println(Serial.list()[5]);
  // Ne pas générer de serialEvent() à moins de recevoir un nouveau caractère
  // Do not generate serialEvent() unless a new char is received
  g_serial.bufferUntil('\n');
  // Vider le buffer pour partir du bon pied
  // Buffer empty for good starting
  ChaineEntree=g_serial.readStringUntil(10);
}

void draw() {
  background(200, 200, 250);
  // Police de caractères en noir 
  // Black font
  fill(0);
  // Légende indicateurs
  // Sliders comments
  text("Consigne °C", g_winW-150, 52);
  text("Mesure °C", g_winW-150, 112);
  text("Chauffage %", g_winW-150, 172);
  text("Sonde en test °C", g_winW-150, 292);
  text("Test sonde chauffage solaire", 100, 380);
  TraiterDonneesSerie();
}

// Lecture des données du port série
// Serial port data extracting
void TraiterDonneesSerie()     
{
  // Lire une chaine ASCII
  // Get a new ASCII string
  ChaineEntree=g_serial.readStringUntil(10);
  if (ChaineEntree != null) {  
    // Enlever les espaces en début et en fin
    // Remove SPACE char at the beginning and at the end
    ChaineEntree = trim(ChaineEntree);     
    String[] MesDonneesChaine = split(ChaineEntree, ","); 
    MaConsigne = MesDonneesChaine[0];
    MaMesure = MesDonneesChaine[1];
    MonPWM = MesDonneesChaine[2];
    MaSondeEnTest = MesDonneesChaine[3];
    println(ChaineEntree);
    sdr1.setLimits(float(MaConsigne), 0, 100f);
    sdr2.setLimits(float(MaMesure), 0, 100f);
    sdr3.setLimits(int(MonPWM), 0f, 100);
    sdr4.setLimits(float(MaSondeEnTest), 0, 100f);
  }
}

// ... Et permettre à MacOS de gérer les évènements...
// ... And now MacOS can handle events...
void handleEvents(GSlider slider) {
}

void handleSliderEvents(GValueControl slider, GEvent event) { 
}

